From 055c8b3fb3002383cc0a839ff38f3292a014f379 Mon Sep 17 00:00:00 2001
From: Thomas  OBADIA <tobadia@pasteur.fr>
Date: Fri, 29 Apr 2022 15:57:10 +0200
Subject: [PATCH] Update references about Magpix-Luminex to also mention
 BioPlex throughout all source code(bis)

---
 FUNCTIONS.R | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/FUNCTIONS.R b/FUNCTIONS.R
index 41fcfef..aeb5cd6 100644
--- a/FUNCTIONS.R
+++ b/FUNCTIONS.R
@@ -41,7 +41,7 @@ runRelativeAntibodyUnits = function(fname1, fname2, MFI_CSV, MFI_N_ANTIGENS, TEM
   ## converts the median fluorescence intensity (MFI) values into relative antibody units.    ##
   ##                                                                                          ##
   ## Input:                                                                                   ##
   ## - Luminex-200 or Magpix output file or Bioplex raw MFI output file(required)             ##
   ## - Plate layout with bleedcode information (optional)                                     ##
   ##                                                                                          ##
   ## Output:                                                                                  ##
@@ -210,9 +210,9 @@ runRelativeAntibodyUnits = function(fname1, fname2, MFI_CSV, MFI_N_ANTIGENS, TEM
       dim(S) #there should be 10 rows
     }
     
     ## Bioplex data input detected
     else if (PLATFORM == "Bioplex") {
-      cat("Guessed MFI input file from a Bioplex platform")
+      cat("Guessed MFI input file from a BioPlex platform")
       
       # In BioPlex outputs, MFI and bead counts are in the same cell with format MFI (counts).
       # Note that the bead counts may not be present, in that case only the MFI is reported.
@@ -498,7 +498,7 @@ getRelativeAntibodyUnits = function(RAW_MFI_FILE_NAME, RAW_MFI_FILE_PATH,
   
   cat("******************Running RAU function******************\n")
   
   # Get Luminex-MagPix full file path
   fname1 = RAW_MFI_FILE_PATH
   
   # Extract working directly of this file
@@ -41,7 +41,7 @@ runRelativeAntibodyUnits = function(fname1, fname2, MFI_CSV, MFI_N_ANTIGENS, TEM
   ##                                                                                          ##
   ## Input:                                                                                   ##
-  ## - Luminex-200 or Magpix output file or Bioplex raw MFI output file(required)             ##
+  ## - Luminex-200 or Magpix output file or BioPlex raw MFI output file(required)             ##
   ## - Plate layout with bleedcode information (optional)                                     ##
   ##                                                                                          ##
@@ -210,9 +210,9 @@ runRelativeAntibodyUnits = function(fname1, fname2, MFI_CSV, MFI_N_ANTIGENS, TEM
     }
     
-    ## Bioplex data input detected
+    ## BioPlex data input detected
     else if (PLATFORM == "Bioplex") {
@@ -498,7 +498,7 @@ getRelativeAntibodyUnits = function(RAW_MFI_FILE_NAME, RAW_MFI_FILE_PATH,
   cat("******************Running RAU function******************\n")
   
-  # Get Luminex-MagPix full file path
+  # Get Luminex-MagPix-BioPlex full file path
   fname1 = RAW_MFI_FILE_PATH
   
-- 
GitLab